#ifndef __JABYENGINE_GPU_TYPES_HPP__
#define __JABYENGINE_GPU_TYPES_HPP__
#include "../jabyengine_defines.h"

namespace GPU {
    struct Color {
        uint8_t red   = 0;
        uint8_t green = 0;
        uint8_t blue  = 0;        

        constexpr Color() = default;
        constexpr Color(uint8_t r, uint8_t g, uint8_t b) : blue(b), green(g), red(r) {
        }

        constexpr uint32_t raw() const {
            return ((this->blue << 16) | (this->green << 8) | this->red);
        }
    };

    template<typename T>
    struct Position {
        T x = 0;
        T y = 0;

        constexpr Position() = default;
        constexpr Position(T x, T y) : x(x), y(y) {
        }
    };

    template<typename T>
    struct Size {
        T width  = 0;
        T height = 0;

        constexpr Size() = default;
        constexpr Size(T w, T h) : width(w), height(h) {
        }
    };

    typedef Position<int16_t>  PositionI16;
    typedef Position<uint16_t> PositionU16;

    typedef Size<int16_t>  SizeI16;
    typedef Size<uint16_t> SizeU16;
}

#endif //!__JABYENGINE_GPU_TYPES_HPP__